package com.hiramine.myexoplayerwithplayerview;

import androidx.appcompat.app.AppCompatActivity;

import android.net.Uri;
import android.os.Bundle;

import com.google.android.exoplayer2.MediaItem;
import com.google.android.exoplayer2.SimpleExoPlayer;
import com.google.android.exoplayer2.ui.PlayerView;

public class MainActivity extends AppCompatActivity
{
	private final String m_strUri = "https://commondatastorage.googleapis.com/gtv-videos-bucket/sample/BigBuckBunny.mp4";
	// 再生動画として、commondatastorage.googleapis.com の gtv-videos-bucket の sample に置いてある「Big Buck Bunny」動画ファイルを使用。
	// Big Buck Bunny
	// 　Copyright (C) 2008 Blender Foundation | peach.blender.org Some Rights Reserved.
	// 　Creative Commons Attribution 3.0 license. https://peach.blender.org/

	private PlayerView      m_playerview;
	private SimpleExoPlayer m_simpleexoplayer;

	@Override
	protected void onCreate( Bundle savedInstanceState )
	{
		super.onCreate( savedInstanceState );
		setContentView( R.layout.activity_main );

		// 動画を再生するビューの取得
		m_playerview = findViewById( R.id.playerview );

		// SimpleExoPlayerの作成と設定
		SimpleExoPlayer.Builder playerbuilder = new SimpleExoPlayer.Builder( this );
		playerbuilder.setSeekBackIncrementMs( 10000 );	// SeekBack 10s
		playerbuilder.setSeekForwardIncrementMs( 10000 ); // SeekForward 10s
		m_simpleexoplayer = playerbuilder.build();

		// 動画を再生するビューとSimpleExoPlayerの紐づけ
		m_playerview.setPlayer( m_simpleexoplayer );

		// MediaItemの作成とSimpleExoPlayerへのセット
		Uri uriVideo = Uri.parse( m_strUri );
		m_simpleexoplayer.setMediaItem( MediaItem.fromUri( uriVideo ) );

		// 再生の準備
		m_simpleexoplayer.prepare();
		// 再生の開始
		m_simpleexoplayer.play();
	}

	// 初回表示時、および、ポーズからの復帰時
	@Override
	protected void onResume()
	{
		super.onResume();

		if( m_bIsPlayingWhenActivityIsPaused )
		{	// Activity pause時に動画再生中なら、動画再生再開
			m_simpleexoplayer.play();
		}
	}

	// アクティビティがフォアグラウンドからバックグラウンドに追いやられた時
	@Override
	protected void onPause()
	{
		// 動画再生中かどうかの取得と保持
		m_bIsPlayingWhenActivityIsPaused = m_simpleexoplayer.isPlaying();
		// 動画再生の一時停止
		m_simpleexoplayer.pause();

		super.onPause();
	}
}